@@ -254,7 +254,7 @@ def bioshed_run_help():
 
     Examples using local storage:
         $ bioshed run --local --aws-env-file .env --inputdir /home/fastq/ zcat /input/my.fastq.gz
-        $ bioshed run --local --inputdir /home/jerry/ cat /input/README.txt
+        $ bioshed run --local cat /input/README.txt
 
     Examples using hybrid environment:
         $ bioshed run bedtools merge s3://folder1/test.bed out::/data/
@@ -264,6 +264,7 @@ def bioshed_run_help():
         program.cat.<TIMESTAMP>.1.log   Log file of program output
         run.<TIMESTAMP>.log             Run log JSON
         out::<OUTPUT_FOLDER>            Output folder for all log and data files.
+                                        If no output folder is specified, then the input folder is used as the output folder.
 
     optional CONFIG-ARGS:
         --local                Run application on local system. Requires docker to be installed.
@@ -271,7 +272,8 @@ def bioshed_run_help():
                                  AWS_ACCESS_KEY_ID=[ID]
                                  AWS_SECRET_ACCESS_KEY=[KEY]
                                  AWS_DEFAULT_REGION=[region]
-        --inputdir <DIR>       Full path of local input directory. Requires --local
+        --inputdir <DIR>       Full path of local input directory. Requires --local.
+                               If no input dir is specified, then the current local directory is used as the input directory.
 
     PROGRAM-ARGS:
         out::<OUTPUT_FOLDER>   Output folder for all log and data files. Specify full remote path.
